@@ -10,7 +10,6 @@ from .function_parameters import FunctionParameters
 from .function_registry import FunctionRegistry
 from .workflow import Workflow
 from .workflow_function import WorkflowFunction
-from ..errors import WorkflowFunctionError
 
 
 class ExecuteWorkflow(ff.DomainService):
@@ -25,22 +24,7 @@ class ExecuteWorkflow(ff.DomainService):
 
         for batch in workflow.batch():
             for function in batch:
-                # try:
                 data = self._execute_function(function, data)
-#                 except Exception as e:
-#                     raise WorkflowFunctionError(f"""
-# Function: {function}
-#
-# Input:
-#
-# {data.debug()}
-#
-# Original Exception:
-#
-# {str(e)}
-#                     """)
-        # for batch in workflow.batch():
-        #     self._batch_process(self._execute_function, [(x, data) for x in batch])
 
         return data
 
